@@ -38,7 +38,6 @@
 
 #include "xfae-window.h"
 #include "xfce4-session-settings-common.h"
-#include "xfce4-session-settings_ui.h"
 
 
 static void
@@ -126,7 +125,7 @@ main (int argc,
   if (G_UNLIKELY (opt_version))
     {
       g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-      g_print ("%s\n", "Copyright (c) 2004-2024");
+      g_print ("%s\n", "Copyright (c) 2004-" COPYRIGHT_YEAR);
       g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
       g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
       g_print ("\n");
@@ -148,10 +147,7 @@ main (int argc,
     return EXIT_FAILURE;
 
   builder = gtk_builder_new ();
-  gtk_builder_add_from_string (builder,
-                               xfce4_session_settings_ui,
-                               xfce4_session_settings_ui_length,
-                               &error);
+  gtk_builder_add_from_resource (builder, "/org/xfce/session/xfce4-session-settings.ui", &error);
 
   if (!builder)
     {
