@@ -258,9 +258,16 @@ name_lost (GDBusConnection *connection,
     {
       gchar *cmd = xfconf_channel_get_string (channel, "/general/WaylandLogoutCommand", NULL);
       if (cmd == NULL)
-        cmd = g_strdup ("loginctl terminate-session ''");
+        {
+          /* if labwc --session is used, just let xfce4-session terminate to exit labwc gracefully */
+          const gchar *compositor_cmd = g_getenv ("XFCE4_SESSION_COMPOSITOR");
+          if (compositor_cmd == NULL
+              || g_strstr_len (compositor_cmd, -1, "labwc") == NULL
+              || g_strstr_len (compositor_cmd, -1, "--session") == NULL)
+            cmd = g_strdup ("loginctl terminate-session ''");
+        }
 
-      if (!g_spawn_command_line_async (cmd, &error))
+      if (cmd != NULL && !g_spawn_command_line_async (cmd, &error))
         g_warning ("Failed to run logout command: %s", error->message);
       g_free (cmd);
     }
@@ -362,7 +369,7 @@ main (int argc, char **argv)
   if (opt_version)
     {
       g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-      g_print ("%s\n", "Copyright (c) 2003-2024");
+      g_print ("%s\n", "Copyright (c) 2003-" COPYRIGHT_YEAR);
       g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
       g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
       g_print ("\n");
