@@ -18,13 +18,13 @@
 #ifndef __XFSM_ERRORS_H__
 #define __XFSM_ERRORS_H__
 
-#include <glib-object.h>
 #include <gio/gio.h>
+#include <glib-object.h>
 
-#define XFSM_TYPE_ERROR  (xfsm_error_get_type ())
-#define XFSM_ERROR       (xfsm_error_get_quark ())
+#define XFSM_TYPE_ERROR (xfsm_error_get_type ())
+#define XFSM_ERROR (xfsm_error_get_quark ())
 
-#define ERROR_MSG(err)   ((err) != NULL ? (err)->message : "Error not set")
+#define ERROR_MSG(err) ((err) != NULL ? (err)->message : "Error not set")
 
 G_BEGIN_DECLS
 
@@ -35,14 +35,17 @@ typedef enum
   XFSM_ERROR_UNSUPPORTED,
 } XfsmError;
 
-GType xfsm_error_get_type (void) G_GNUC_CONST;
-GQuark xfsm_error_get_quark (void) G_GNUC_CONST;
+GType
+xfsm_error_get_type (void) G_GNUC_CONST;
+GQuark
+xfsm_error_get_quark (void) G_GNUC_CONST;
 
-void throw_error (GDBusMethodInvocation *context,
-                  gint                   error_code,
-                  const gchar           *format,
-                  ...);
+void
+throw_error (GDBusMethodInvocation *context,
+             gint error_code,
+             const gchar *format,
+             ...);
 
 G_END_DECLS
 
-#endif  /* !__XFSM_ERRORS_H__ */
+#endif /* !__XFSM_ERRORS_H__ */
