@@ -29,8 +29,10 @@ G_BEGIN_DECLS;
 
 typedef struct _XfsmFadeout XfsmFadeout;
 
-XfsmFadeout *xfsm_fadeout_new     (GdkDisplay  *display);
-void         xfsm_fadeout_destroy (XfsmFadeout *fadeout);
+XfsmFadeout *
+xfsm_fadeout_new (GdkDisplay *display);
+void
+xfsm_fadeout_destroy (XfsmFadeout *fadeout);
 
 G_END_DECLS;
 
